{
  config,
  lib,
  pkgs,
  pkgs-4a3fc4cf7,
  ...
}:

{
  services = {
    transmission = {
      enable = true;
      package = pkgs-4a3fc4cf7.transmission_4;
      home = "/var/lib/transmission";
      group = "medias";
      settings = {
        rpc-bind-address = "127.0.0.1";
        rpc-port = 9091;
        rpc-host-whitelist = "*";
        rpc-whitelist-enabled = false;
        peer-port = 51413;
        incomplete-dir = "/mnt/medias/incomplete";
        download-dir = "/mnt/medias/torrent";
      };
    };

    radarr.enable = true;
    sonarr.enable = true;
    prowlarr.enable = true;
    recyclarr = {
      enable = true;
      configuration = {
        radarr.radarr_main = {
          api_key = {
            _secret = "/run/credentials/recyclarr.service/radarr-api_key";
          };
          base_url = "http://localhost:7878";
          include = [
            {
              template = "radarr-quality-definition-movie";
            }
            {
              template = "radarr-quality-profile-hd-bluray-web-french-multi-vo";
            }
            {
              template = "radarr-custom-formats-hd-bluray-web-french-multi-vo";
            }
          ];
          custom_formats = [
            # ===== Versions françaises =====
            {
              trash_ids = [
                "404c08fd0bd67f39b4d8e5709319094e" # VFF
              ];
              assign_scores_to = {
                name = "FR-MULTi-VO-HD";
                score = 101;
              };
            }
            {
              trash_ids = [
                "4cafa20d5584f6ba1871d1b8941aa3cb" # VOF
              ];
              assign_scores_to = {
                name = "FR-MULTi-VO-HD";
                score = 0;
              };
            }
            {
              trash_ids = [
                "52772f1cad6b5d26c2551f79bc538a50" # VFI
              ];
              assign_scores_to = {
                name = "FR-MULTi-VO-HD";
                score = 0;
              };
            }
            {
              trash_ids = [
                "29b5f7b1a5f20f64228786c3ab1bdc7d" # VF2
              ];
              assign_scores_to = {
                name = "FR-MULTi-VO-HD";
                score = 101;
              };
            }
            {
              trash_ids = [
                "b6ace47331a1d3b77942fc18156f6df6" # VFQ
              ];
              assign_scores_to = {
                name = "FR-MULTi-VO-HD";
                score = -101;
              };
            }
            {
              trash_ids = [
                "f7caa1942be5cc547c266bd3dbc2cda9" # VOQ
              ];
              assign_scores_to = {
                name = "FR-MULTi-VO-HD";
                score = 0;
              };
            }
            {
              trash_ids = [
                "95aa50f71a01c82354a7a2b385f1c4d8" # VQ
              ];
              assign_scores_to = {
                name = "FR-MULTi-VO-HD";
                score = 0;
              };
            }
            {
              trash_ids = [
                "b3fb499641d7b3c2006be1d9eb014cb3" # VFB
              ];
              assign_scores_to = {
                name = "FR-MULTi-VO-HD";
                score = 0;
              };
            }
          ];
        };
        sonarr.sonarr_main = {
          api_key = {
            _secret = "/run/credentials/recyclarr.service/sonarr-api_key";
          };
          base_url = "http://localhost:8989";
          include = [
            {
              template = "sonarr-quality-definition-series";
            }
            {
              template = "sonarr-v4-quality-profile-bluray-web-1080p-french-multi-vo";
            }
            {
              template = "sonarr-v4-custom-formats-bluray-web-1080p-french-multi-vo";
            }
          ];
          custom_formats = [
            # ===== Versions françaises =====
            {
              trash_ids = [
                "2c29a39a4fdfd6d258799bc4c09731b9" # VFF
              ];
              assign_scores_to = {
                name = "FR-MULTi-VO-WEB-1080p";
                score = 101;
              };
            }
            {
              trash_ids = [
                "7ae924ee9b2f39df3283c6c0beb8a2aa" # VOF
              ];
              assign_scores_to = {
                name = "FR-MULTi-VO-WEB-1080p";
                score = 0;
              };
            }
            {
              trash_ids = [
                "b6816a0e1d4b64bf3550ad3b74b009b6" # VFI
              ];
              assign_scores_to = {
                name = "FR-MULTi-VO-WEB-1080p";
                score = 0;
              };
            }
            {
              trash_ids = [
                "34789ec3caa819f087e23bbf9999daf7" # VF2
              ];
              assign_scores_to = {
                name = "FR-MULTi-VO-WEB-1080p";
                score = 101;
              };
            }
            {
              trash_ids = [
                "7a7f4e4f58bd1058440236d033a90b67" # VFQ
              ];
              assign_scores_to = {
                name = "FR-MULTi-VO-WEB-1080p";
                score = -101;
              };
            }
            {
              trash_ids = [
                "802dd70b856c423a9b0cb7f34ac42be1" # VOQ
              ];
              assign_scores_to = {
                name = "FR-MULTi-VO-WEB-1080p";
                score = 0;
              };
            }
            {
              trash_ids = [
                "82085412d9a53ba8d8e46fc624eb701d" # VQ
              ];
              assign_scores_to = {
                name = "FR-MULTi-VO-WEB-1080p";
                score = 0;
              };
            }
            {
              trash_ids = [
                "0ce1e39a4676c6692ce47935278dac76" # VFB
              ];
              assign_scores_to = {
                name = "FR-MULTi-VO-WEB-1080p";
                score = 0;
              };
            }
          ];

        };
      };
    };

    jellyfin.enable = true;
    slimserver.enable = true;
  };

  systemd.services.transmission.serviceConfig = {
    BindPaths = [ "/mnt/medias" ];
    LimitNOFILE = 1048576;
  };

  systemd.services.recyclarr.serviceConfig.LoadCredential = [
    "radarr-api_key:/mnt/secrets/radarr-api_key"
    "sonarr-api_key:/mnt/secrets/sonarr-api_key"
  ];

  networking = {
    firewall.allowedTCPPorts = [
      config.services.transmission.settings.peer-port
    ];

    firewall.allowedUDPPorts = [
      config.services.transmission.settings.peer-port
    ];
  };
}
